@@ -1,13 +1,14 @@
 package Test::Smoke::BuildCFG;
 use strict;
 
-# $Id: BuildCFG.pm 230 2003-07-15 02:56:14Z abeltje $
+# $Id: BuildCFG.pm 431 2003-09-22 19:33:52Z abeltje $
 use vars qw( $VERSION );
-$VERSION = '0.002';
+$VERSION = '0.004';
 
 use Cwd;
 use File::Spec;
 require File::Path;
+use Test::Smoke::Util qw( skip_config );
 
 my %CONFIG = (
     df_v      => 0,
@@ -69,6 +70,37 @@ sub new {
     $self->read_parse( $config );
 }
 
+=item Test::Smoke::BuildCFG->continue( $logfile[, $cfgname, %options] )
+
+[Constructor | public]
+
+Initialize a new object without the configurations that have already
+been fully processed. If *all* configurations have been processed,
+just pass the equivalent of the C<new()> method.
+
+=cut
+
+sub continue {
+    my $proto = shift;
+    my $class = ref $proto ? ref $proto : $proto;
+
+    my $logfile = shift;
+
+    my $self = $class->new( @_ );
+    $self->{_continue} = 1;
+    return $self unless $logfile && -f $logfile;
+
+    my %seen = __get_smoked_configs( $logfile );
+    my @not_seen = ();
+    foreach my $config ( $self->configurations ) {
+        push @not_seen, $config unless exists $seen{ "$config" } ||
+                                       skip_config( $config );
+    }
+    return $self unless @not_seen;
+    $self->{_list} = \@not_seen;
+    return $self;
+}
+
 =item Test::Smoke::BuildCFG->config( $key[, $value] )
 
 [ Accessor | Public ]
@@ -156,16 +188,23 @@ sub _read {
         $self->{_buildcfg} = do { local $/; <BUILDCFG> };
         $vmsg = "anonymous filehandle";
     } else {
-        unless ( open BUILDCFG, "< $nameorref" ) {
-            require Carp;
-            Carp::carp "Error opening buildconfigurations: $!";
-            my $dft = $self->default_buildcfg();
-            return $self->_read( \$dft );
-        }
-        $self->{_buildcfg} = do { local $/; <BUILDCFG> };
-        close BUILDCFG;
-        $vmsg = $nameorref;
+        if ( $nameorref ) {
+            if ( open BUILDCFG, "< $nameorref" ) {
+                $self->{_buildcfg} = do { local $/; <BUILDCFG> };
+                close BUILDCFG;
+                $vmsg = $nameorref;
+            } else {
+                require Carp;
+                Carp::carp "Cannot read buildconfigurations ($nameorref): $!";
+                $self->{_buildcfg} = $self->default_buildcfg();
+                $vmsg = "internal content";
+            }
+        } else { # Allow intentional default_buildcfg()
+            $self->{_buildcfg} = $self->default_buildcfg();
+            $vmsg = "internal content";
+        } 
     }
+    $vmsg .= "[continue]" if $self->{_continue};
     $self->{v} and print "Reading build configurations from $vmsg\n";
 }
 
@@ -202,9 +241,10 @@ sub _parse {
     $self->{v} > 1 and printf "Found %d raw-sections\n", scalar @sections;
 
     foreach my $section ( @sections ) {
+        chomp $section;
         my $index = 0;
-        my %opts = map { $_ => $index++ } map { s/^\s+$//; $_ }
-            grep !/^#/ => split /\n/, $section;
+        my %opts = map { s/^\s+$//; $_ => $index++ }
+            grep !/^#/ => split /\n/, $section, -1;
         # Skip empty sections
         next if (keys %opts == 0) or (exists $opts{ "" } and keys %opts == 1);
 
@@ -229,9 +269,12 @@ sub _parse {
 
         } else { # Buildopt section
             push @{ $self->{_sections} }, 
-                 [ sort {$opts{ $a } <=> $opts{ $b}} keys %opts ];
+                 [ sort {$opts{ $a } <=> $opts{ $b }} keys %opts ];
         }
     }
+    # Make sure we have at least *one* section
+    push @{ $self->{_sections} }, [ "" ] unless @{ $self->{_sections} };
+
     $self->{v} > 1 and printf "Left with %d parsed sections\n", 
                               scalar @{ $self->{_sections} };
     $self->_serialize;
@@ -301,6 +344,32 @@ sub configurations {
     @{ $self->{_list} };
 }
 
+=item __get_smoked_configs( $logfile )
+
+Parse the logfile and return a hash(ref) of already processed
+configurations.
+
+=cut
+
+sub __get_smoked_configs {
+    my( $logfile ) = @_;
+
+    my %conf_done = ( );
+    local *LOG;
+    if ( open LOG, "< $logfile" ) {
+        my $conf;
+        # A Configuration is done when we detect a new Configuration:
+        # or the phrase "Finished smoking $patch"
+        while ( <LOG> ) {
+            s/^Configuration:\s*// || /^Finished smoking/ or next;
+            $conf and $conf_done{ $conf }++;
+            chomp; $conf = $_;
+        }
+        close LOG;
+    }
+    return wantarray ? %conf_done : \%conf_done;
+}
+
 =item Test::Smoke::BuildCFG->default_buildcfg()
 
 This is a constant that returns a textversion of the default 
@@ -312,16 +381,16 @@ sub default_buildcfg() {
 
     return <<__EOCONFIG__;
 
-=
+= Build all configurations with and without ithreads
 
 -Duseithreads
-=
+= Build perl with these options
 -Uuseperlio
 
 -Duse64bitint
 -Duselongdouble
 -Dusemorebits
-=
+= All configurations with and without -DDEBUGGING
 /-DDEBUGGING/
 
 -DDEBUGGING
@@ -469,6 +538,38 @@ sub any_arg {
     return $ok;
 }
 
+=item $buildcfg->args_eq( $args )
+
+C<args_eq()> takes a string of config arguments and returns true if
+C<$self> has exactly the same args as the C<$args> has.
+
+There is the small matter of default_args (dfopts) kept as a Class
+variable in L<Test::Smoke::BuildCFG>!
+
+=cut
+
+sub args_eq {
+    my $self = shift;
+    my $args = shift;
+
+    my $default_args = join "|", sort { 
+        length($b) <=> length($a) 
+    } quotewords( '\s+', 1, Test::Smoke::BuildCFG->config( 'dfopts' ) );
+
+    my %copy = map { ( $_ => undef ) }
+        grep !/$default_args/ => keys %{ $self->[2] };
+    my @s_args = grep !/$default_args/ => quotewords( '\s+', 1, $args );
+    my @left;
+    while ( my $option = pop @s_args ) {
+        if ( exists $copy{ $option } ) {
+            delete $copy{ $option };
+        } else {
+            push @left, $option;
+        }
+    }
+    return (@left || keys %copy) ? 0 : 1;
+}
+
 1;
 
 =back
