@@ -1,7 +1,7 @@
 package Test::Smoke::Smoker;
 use strict;
 
-# $Id: Smoker.pm 347 2003-08-08 18:15:39Z abeltje $
+# $Id: Smoker.pm 433 2003-09-23 18:26:59Z abeltje $
 use vars qw( $VERSION );
 $VERSION = '0.005';
 
@@ -27,6 +27,7 @@ my %CONFIG = (
     df_w32args        => [ ],
 
     df_makeopt        => "",
+    df_testmake       => 'make',
 );
 
 # Define some constants that we can use for
@@ -377,7 +378,7 @@ sub make_test {
         $self->ttylog( "PERLIO = $perlio_logmsg\t" );
 
         unless ( $self->{run} ) {
-            $self->ttylog( "bailing out ...\n" );
+            $self->ttylog( "bailing out (--norun)...\n" );
             next;
 	}
 
@@ -391,7 +392,7 @@ sub make_test {
             chdir ".." or die "unable to chdir () out of 'win32'";
         } else {
             local $ENV{PERL} = "./perl";
-            open TST, "make $test_target |" or do {
+            open TST, "$self->{testmake} $test_target |" or do {
                 use Carp;
                 Carp::carp "Cannot fork 'make _test': $!";
                 next;
@@ -466,7 +467,7 @@ sub extend_with_harness {
             my( $name, $fail ) = 
                 m/(\S+\.t)\s+.+%\s+([\d?]+(?:[-\s]+\d+)*)/;
             if ( $name ) {
-                my $dots = '.' x (30 - length $name );
+                my $dots = '.' x (40 - length $name );
                 "    $name${dots}FAILED $fail\n";
             } else {
                 ( $fail ) = m/^\s+(\d+(?:[-\s]+\d+)*)/;
@@ -481,7 +482,8 @@ sub extend_with_harness {
         $harness_out =~ s/^\s*$//;
         if ( $harness_all_ok ) {
             $harness_out ||= @nok
-                ? "Inconsistent testresults:\n" . join "", map "    $_" => @nok
+                ? "Inconsistent test results (between _test and harness):\n" . 
+                  join "", map "    $_" => @nok
                 : "All tests successful.";
         } else {
             $harness_out ||= join "", map "    $_" => @nok;
