@@ -1,8 +1,9 @@
 package Test::Smoke::SourceTree;
 use strict;
 
+# $Id: SourceTree.pm 417 2003-09-03 09:34:05Z abeltje $
 use vars qw( $VERSION @EXPORT_OK %EXPORT_TAGS );
-$VERSION = '0.003'; # $Id: SourceTree.pm 151 2003-06-06 14:34:06Z abeltje $
+$VERSION = '0.004';
 
 use File::Spec;
 use File::Find;
@@ -129,7 +130,7 @@ sub abs2mani {
     return join '/', @dirs;
 }
 
-=item $tree->check_MANIFEST( )
+=item $tree->check_MANIFEST( @ignore )
 
 C<check_MANIFEST()> reads the B<MANIFEST> file from C<< $$self >> and
 compares it with the actual contents of C<< $$self >>.
@@ -143,20 +144,16 @@ value of either B<ST_MISSING> (not in directory) or B<ST_UNDECLARED>
 sub check_MANIFEST {
     my $self = shift;
 
-    my $manifile = File::Spec->rel2abs( 
-        File::Spec->catfile($$self, 'MANIFEST' ) );
-    local *MANIFEST;
-    open MANIFEST, "< $manifile" or 
-        croak( "Can't open '$manifile': $!" );
+    my %manifest = %{ $self->_read_mani_file( 'MANIFEST' ) };
 
-    my %manifest = ( ".patch" => ST_MISSING, map { 
-        s/\s.*$//;
-        ( $_ => ST_MISSING );
-    } <MANIFEST> );
-    close MANIFEST;
+    my %ignore = map { 
+        $_ => undef 
+    } ( ".patch", "MANIFEST.SKIP", @_ ), 
+      keys %{ $self->_read_mani_file( 'MANIFEST.SKIP', 1 ) };
 
     # Walk the tree, remove all found files from %manifest
-    # and add other files to %manifest
+    # and add other files to %manifest 
+    # unless they are in the ignore list
     require File::Find;
     File::Find::find( sub {
         -f or return;
@@ -164,13 +161,42 @@ sub check_MANIFEST {
         if ( exists $manifest{ $mani_name } ) {
             delete $manifest{ $mani_name };
         } else {
-            $manifest{ $mani_name } = ST_UNDECLARED;
+            $manifest{ $mani_name } = ST_UNDECLARED
+                unless exists $ignore{ $mani_name };
         }
     }, $$self );
 
     return \%manifest;
 } 
 
+=item $self->_read_mani_file( $path[, $no_croak] )
+
+C<_read_mani_file()> reads the contents of C<$path> like it is a
+MANIFEST typeof file and returns a ref to hash with all values set
+C<ST_MISSING>.
+
+=cut
+
+sub _read_mani_file {
+    my $self = shift;
+    my( $path, $no_croak ) = @_;
+
+    my $manifile = $self->mani2abs( $path );
+    local *MANIFEST;
+    open MANIFEST, "< $manifile" or do {
+        $no_croak and return { };
+        croak( "Can't open '$manifile': $!" );
+    };
+
+    my %manifest = map { 
+        m|(\S+)|;
+        ( $1 => ST_MISSING );
+    } <MANIFEST>;
+    close MANIFEST;
+
+    return \%manifest;
+}
+
 =item $tree->clean_from_MANIFEST( )
 
 C<clean_from_MANIFEST()> removes all files from the source-tree that are
@@ -181,7 +207,7 @@ not declared in the B<MANIFEST> file.
 sub clean_from_MANIFEST {
     my $self = shift;
 
-    my $mani_check = $self->check_MANIFEST;
+    my $mani_check = $self->check_MANIFEST( @_ );
     my @to_remove = grep $mani_check->{ $_ } == ST_UNDECLARED 
         => keys %$mani_check;
 
